"""
A package to handle GNU Scientific Library (GSL) constants for python.
"""

import gslconsts.consts
